@@ -16,27 +16,30 @@ cut.ff <- function(x, breaks, ...){
    
    #### borrowed code from cut.default
 	if (length(breaks) == 1) {
-		if (is.na(breaks) | breaks < 2) 
+		if (is.na(breaks) || breaks < 2) 
 			stop("invalid number of intervals")
 		nb <- as.integer(breaks + 1)
 		dx <- diff(rx <- range(x, na.rm = TRUE))
 		if (dx == 0) 
 			dx <- abs(rx[1])
 		breaks <- seq.int( rx[1] - dx/1000
-                       , rx[2L] + dx/1000
-                       , length.out = nb
-                       )
+                     , rx[2L] + dx/1000
+                     , length.out = nb
+                     )
 	}
    ####
    
    args <- list(...)
-   
+   args$by <- NULL
    args$breaks <- breaks
    for (i in chunk(x, ...)){
      args$x <- x[i]
+     res <- do.call(cut, args)
      f <- ffappend( f
                   , do.call(cut, args)
-               )
+                  , res
+                  , adjustvmode=FALSE
+                  )
    }
    f
 }
