@@ -16,23 +16,17 @@ subset.ff <- function(x, subset, ...){
 	y
 }
 
-subset.ffdf <- function(x, subset, ...){
-	y <- clone(x)
-	n <- 0
-	#subset <- eval(expression(substitute(subset)))
-	#print(subset)
-	#TODO check if subset is an expression or logical vector. If so, then idx vector
-	for (i in chunk(x)){
-	   dat <- x[i,]
-	   row.names(dat) <- min(i):max(i)
-	   #sel <- eval(substitute(subset), dat, parent.frame())
-	   dat <- dat[subset[i],]
-	   s <- nrow(dat) 
-	   if (s > 0){
-	      y[(n+1):(n+s),] <- dat
-		  n <- n + s
-	   }
-	}
-	nrow(y) <- n
-	y 
-}
\ No newline at end of file
+subset.ffdf <- function(x, subset, select, ...){
+  ss <- as.expression(substitute(subset))
+  try(ss <- subset, silent=TRUE)
+  idx <- ffwhich(x, ss)
+  x[idx,select]
+}
+
+
+# quick testing
+# x <- as.ffdf(iris)
+# log <- x$Species == "setosa"
+# 
+# subset(x, Species=="setosa")
+#ffwhich(x, log)
\ No newline at end of file
